@@ -9,6 +9,8 @@ from django.contrib.contenttypes import generic
 
 from tendenci.core.perms.utils import has_perm
 from tendenci.apps.invoices.managers import InvoiceManager
+from tendenci.apps.accountings.utils import (make_acct_entries,
+                                    make_acct_entries_reversing)
 
 
 class Invoice(models.Model):
@@ -20,9 +22,13 @@ class Invoice(models.Model):
 
     title = models.CharField(max_length=150, blank=True, null=True)
     #user
-    creator = models.ForeignKey(User, related_name="invoice_creator",  null=True, on_delete=models.SET_NULL)
+    creator = models.ForeignKey(User, related_name="invoice_creator",
+                                null=True,
+                                on_delete=models.SET_NULL)
     creator_username = models.CharField(max_length=50, null=True)
-    owner = models.ForeignKey(User, related_name="invoice_owner", null=True, on_delete=models.SET_NULL)
+    owner = models.ForeignKey(User, related_name="invoice_owner",
+                              null=True,
+                              on_delete=models.SET_NULL)
     owner_username = models.CharField(max_length=50, null=True)
     #dates
     create_dt = models.DateTimeField(auto_now_add=True)
@@ -37,14 +43,23 @@ class Invoice(models.Model):
                                      default='estimate')
     status = models.BooleanField(default=True)
     estimate = models.BooleanField(default=1)
-    payments_credits = models.DecimalField(max_digits=15, decimal_places=2, blank=True, default=0)
-    balance = models.DecimalField(max_digits=15, decimal_places=2, blank=True, default=0)
-    total = models.DecimalField(max_digits=15, decimal_places=2, blank=True)
+    payments_credits = models.DecimalField(max_digits=15,
+                                           decimal_places=2,
+                                           blank=True,
+                                           default=0)
+    balance = models.DecimalField(max_digits=15,
+                                  decimal_places=2,
+                                  blank=True,
+                                  default=0)
+    total = models.DecimalField(max_digits=15,
+                                decimal_places=2,
+                                blank=True)
     #discount info
-    discount_code = models.CharField(_('Discount Code'), max_length=100,
+    discount_code = models.CharField(_('Discount Code'),
+                                     max_length=100,
                                      blank=True, null=True)
-    discount_amount = models.DecimalField(_('Discount Amount'), 
-                                          max_digits=10, 
+    discount_amount = models.DecimalField(_('Discount Amount'),
+                                          max_digits=10,
                                           decimal_places=2,
                                           default=0)
     #other
@@ -70,7 +85,9 @@ class Invoice(models.Model):
     tax = models.DecimalField(max_digits=6, decimal_places=4, default=0)
     #bill/ ship
     bill_to = models.CharField(max_length=120, blank=True)
-    bill_to_first_name = models.CharField(max_length=100, blank=True, null=True)
+    bill_to_first_name = models.CharField(max_length=100,
+                                          blank=True,
+                                          null=True)
     bill_to_last_name = models.CharField(max_length=100, blank=True, null=True)
     bill_to_company = models.CharField(max_length=100, blank=True, null=True)
     bill_to_address = models.CharField(max_length=250, blank=True, null=True)
@@ -96,9 +113,14 @@ class Invoice(models.Model):
     ship_to_address_type = models.CharField(max_length=50, blank=True, null=True)
     ship_date = models.DateTimeField()
     ship_via = models.CharField(max_length=50, blank=True)
-    shipping = models.DecimalField(max_digits=6, decimal_places=2, default=0)
-    shipping_surcharge = models.DecimalField(max_digits=6, decimal_places=2, default=0)
-    box_and_packing = models.DecimalField(max_digits=6, decimal_places=2, default=0)
+    shipping = models.DecimalField(max_digits=6, decimal_places=2,
+                                   default=0)
+    shipping_surcharge = models.DecimalField(max_digits=6,
+                                             decimal_places=2,
+                                             default=0)
+    box_and_packing = models.DecimalField(max_digits=6,
+                                          decimal_places=2,
+                                          default=0)
 
     objects = InvoiceManager()
 
@@ -200,25 +222,23 @@ class Invoice(models.Model):
         return boo
 
     def tender(self, user):
-        from tendenci.apps.accountings.utils import make_acct_entries
-        """ mark it as tendered if we have records """ 
+        """ mark it as tendered if we have records """
         if not self.is_tendered:
             # make accounting entry
             make_acct_entries(user, self, self.total)
-            
+
             self.estimate = False
             self.status_detail = 'tendered'
             self.status = 1
             self.tender_date = datetime.now()
             self.save()
         return True
-            
-    
+
     # if this invoice allows view by user2_compare
     def allow_view_by(self, user2_compare, guid=''):
         if user2_compare.profile.is_superuser:
             return True
-        
+
         if has_perm(user2_compare, 'invoices.view_invoice'):
             return True
 
@@ -233,25 +253,26 @@ class Invoice(models.Model):
 
     def allow_payment_by(self, user2_compare,  guid=''):
         return self.allow_view_by(user2_compare,  guid)
-    
+
     # if this invoice allows edit by user2_compare
     def allow_edit_by(self, user2_compare, guid=''):
         boo = False
         if user2_compare.is_superuser:
             boo = True
         else:
-            if user2_compare and user2_compare.id > 0: 
+            if user2_compare and user2_compare.id > 0:
                 if has_perm(user2_compare, 'invoices.change_invoice'):
                     return True
-        
-                if self.creator == user2_compare or self.owner == user2_compare:
+
+                if self.creator == user2_compare or \
+                        self.owner == user2_compare:
                     if self.status == 1:
                         # user can only edit a non-tendered invoice
                         if not self.is_tendered:
                             boo = True
             else:
-                if self.guid and self.guid == guid: # for anonymous user
-                    if self.status == 1 and not self.is_tendered:  
+                if self.guid and self.guid == guid:  # for anonymous user
+                    if self.status == 1 and not self.is_tendered:
                         boo = True
         return boo
 
@@ -260,8 +281,8 @@ class Invoice(models.Model):
         Updates the invoice balance by adding
         accounting entries.
         """
-        from tendenci.apps.accountings.utils import make_acct_entries
-        if self.is_tendered:
+
+        if self.is_tendered and self.balance > 0:
             self.balance -= amount
             self.payments_credits += amount
             self.save()
@@ -269,6 +290,10 @@ class Invoice(models.Model):
             # Make the accounting entries here
             make_acct_entries(user, self, amount)
 
+            return True
+
+        return False
+
     def void_payment(self, user, amount):
         self.balance += amount
         self.payments_credits -= amount
@@ -280,3 +305,5 @@ class Invoice(models.Model):
             payment.status_detail = 'void'
             payment.save()
 
+        # reverse accounting entries
+        make_acct_entries_reversing(user, self, amount)
