@@ -50,20 +50,32 @@ class File(TendenciBaseModel):
     content_type = models.ForeignKey(ContentType, blank=True, null=True)
     object_id = models.IntegerField(blank=True, null=True)
     is_public = models.BooleanField(default=True)
-    group = models.ForeignKey(Group, null=True,
-        default=get_default_group, on_delete=models.SET_NULL)
+    group = models.ForeignKey(
+        Group, null=True, default=get_default_group, on_delete=models.SET_NULL)
     tags = TagField(null=True, blank=True)
     categories = generic.GenericRelation(CategoryItem, object_id_field="object_id", content_type_field="content_type")
 
-    perms = generic.GenericRelation(ObjectPermission,
-                                          object_id_field="object_id",
-                                          content_type_field="content_type")
+    perms = generic.GenericRelation(
+        ObjectPermission,
+        object_id_field="object_id",
+        content_type_field="content_type")
 
     objects = FileManager()
 
     class Meta:
         permissions = (("view_file", "Can view file"),)
 
+    @models.permalink
+    def get_absolute_url(self):
+        return ("file", [self.pk])
+
+    @models.permalink
+    def get_absolute_download_url(self):
+        return ("file", [self.pk, 'download'])
+
+    def __unicode__(self):
+        return self.get_name()
+
     @property
     def category_set(self):
         items = {}
@@ -139,8 +151,7 @@ class File(TendenciBaseModel):
 
         # map file-type to extension
         types = {
-            'image': ('.jpg', '.jpeg', '.gif', '.png', 
-                      '.tif', '.tiff', '.bmp'),
+            'image': ('.jpg', '.jpeg', '.gif', '.png', '.tif', '.tiff', '.bmp'),
             'text': ('.txt', '.doc', '.docx'),
             'spreadsheet': ('.csv', '.xls', '.xlsx'),
             'powerpoint': ('.ppt', '.pptx'),
@@ -230,23 +241,12 @@ class File(TendenciBaseModel):
 
         return unicode()
 
-    @models.permalink
-    def get_absolute_url(self):
-        return ("file", [self.pk])
-
-    @models.permalink
-    def get_absolute_download_url(self):
-        return ("file", [self.pk, 'download'])
-
-    def __unicode__(self):
-        return self.get_name()
-
     def is_public_file(self):
-        return all([self.is_public,
+        return all([
+            self.is_public,
             self.allow_anonymous_view,
             self.status,
-            self.status_detail.lower() == "active"]
-            )
+            self.status_detail.lower() == "active"])
 
     def get_file_public_url(self):
         if self.is_public_file():
